Description Usage Arguments Value Author(s)
interval_mid Calculates the mid-point of an interval to be used as an
attractive label for plot axes when binning an axis. Intervals as defined by
functions such as base-R cut.
1 | interval_mid(x, dp = 1)
|
x |
A numeric vector or data frame column with intervals typically
applied using the base-R |
dp |
A numeric scalar (default 1) defining the number of decimal places
for the base-R |
A numeric vector containing the mid points of the intervals.
Alex M Trueman
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.